@@ -6,10 +6,10 @@ pub mod alias_dto;
 pub use self::alias_dto::AliasDto;
 pub mod alias_projection;
 pub use self::alias_projection::AliasProjection;
-pub mod attachment_entity;
-pub use self::attachment_entity::AttachmentEntity;
 pub mod attachment_meta_data;
 pub use self::attachment_meta_data::AttachmentMetaData;
+pub mod attachment_projection;
+pub use self::attachment_projection::AttachmentProjection;
 pub mod basic_auth_options;
 pub use self::basic_auth_options::BasicAuthOptions;
 pub mod bulk_send_email_options;
